@@ -5,13 +5,17 @@
 #include <QProcess>
 #include <QTest>
 
+#ifdef Q_OS_LINUX
+#include <sys/param.h>
+#endif
+
 #include "directoryIterator.h"
 #include "test-config.h"
 
 class DirectoryIteratorTest : public QObject
 {
     Q_OBJECT
-    const QString m_tree = QFINDTESTDATA("iterator-tree");
+    QString m_tree = QFINDTESTDATA("iterator-tree");
 private Q_SLOTS:
     void testIterate()
     {
@@ -62,7 +66,7 @@ private Q_SLOTS:
 #elif defined(Q_OS_FREEBSD)
         // CI keeps changing, we don't assert anything for freebsd.
 #else
-        QCOMPARE(file.size, 16 * S_BLKSIZE);
+        QCOMPARE(file.size, 16 * DEV_BSIZE);
 #endif
 
         if (withSymlink) {
@@ -71,7 +75,7 @@ private Q_SLOTS:
             QVERIFY(!symlink.isDir);
             QVERIFY(!symlink.isFile);
             QVERIFY(symlink.isSkipable);
-            // size of skippables doesn't matter
+            // size of skipables doesn't matter
         }
 
         if (withLink) {
@@ -89,7 +93,7 @@ private Q_SLOTS:
             QVERIFY(symlink.isDuplicate || file.isDuplicate);
             // Now make sure only one is a duplicate also
             QVERIFY(symlink.isDuplicate != file.isDuplicate);
-            QCOMPARE(symlink.size, 16 * S_BLKSIZE);
+            QCOMPARE(symlink.size, 16 * DEV_BSIZE);
 #endif
         }
     }
